summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--gui_win.figbin19669 -> 19678 bytes
-rw-r--r--gui_win.m16
2 files changed, 8 insertions, 8 deletions
diff --git a/gui_win.fig b/gui_win.fig
index 245b2ea..93b2578 100644
--- a/gui_win.fig
+++ b/gui_win.fig
Binary files differ
diff --git a/gui_win.m b/gui_win.m
index 2b843bd..8a98241 100644
--- a/gui_win.m
+++ b/gui_win.m
@@ -22,7 +22,7 @@ function varargout = gui_win(varargin)
% Edit the above text to modify the response to help gui_win
-% Last Modified by GUIDE v2.5 18-Sep-2012 14:31:11
+% Last Modified by GUIDE v2.5 18-Sep-2012 14:56:06
% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
@@ -230,7 +230,7 @@ if get(handles.button2singlerun,'Value')
end;
% This executes when we do the continuous run
-if get(handles.button2comtinuousrun,'Value')
+if get(handles.button2continuous_run,'Value')
while get(handles.button2start,'Value') > 0
grab_image_and_update_display(handles);
end;
@@ -820,14 +820,14 @@ function button2fit_ButtonDownFcn(hObject, eventdata, handles)
% handles structure with handles and user data (see GUIDATA)
-% --- Executes on key press with focus on button2comtinuousrun and none of its controls.
-function button2comtinuousrun_KeyPressFcn(hObject, eventdata, handles)
-% hObject handle to button2comtinuousrun (see GCBO)
+% vim: tabstop=4 shiftwidth=4 expandtab
+
+
+% --- Executes on key press with focus on button2continuous_run and none of its controls.
+function button2continuous_run_KeyPressFcn(hObject, eventdata, handles)
+% hObject handle to button2continuous_run (see GCBO)
% eventdata structure with the following fields (see UICONTROL)
% Key: name of the key that was pressed, in lower case
% Character: character interpretation of the key(s) that was pressed
% Modifier: name(s) of the modifier key(s) (i.e., control, shift) pressed
% handles structure with handles and user data (see GUIDATA)
-
-
-% vim: tabstop=4 shiftwidth=4 expandtab